/*
program: obp.cmd
type:    Classic REXX
purpose: BSO purger
version: 0.1
author:  Aleksey Lubkov (2:5020/1834@fidonet)
note:    Tested with Zip 2.2 by Mark Adler
                     UnZip 5.40 by Info-Zip
                     AllFix 1.11.3 by Harald Harms
                     FastEcho 1.46 by Tobias Burchhardt
                     T-Mail 26.07 by Andy Elkin
*/

/* User settings */

defzone = '2'
   /* your zone */

ob = 'd:\fido\t-mail\outbound'
   /* main outbound */

zipper = 'd:\fido\arc'
   /* path to Zip and UnZip */

pkts = 'yes'
   /* do you want to process .pkt? */

age_p = '7'
   /* max age for packets (no matter if pkts = 'no') */

tics = 'yes'
   /* do you want to process .tic? */

age_t = '7'
   /* max age for tics (no matter if tics = 'no') */

/* Load system libraries */

call RxFuncAdd 'SysFileTree', 'RexxUtil', 'SysFileTree'
call RxFuncAdd 'SysFileDelete', 'RexxUtil', 'SysFileDelete'

/* Main body */

if (pkts = 'no') & (tics = 'no')
  then
    do
      say
      say 'Are you nuts?!?'
      return
    end
  
parse upper var ob ob
say
say 'Checking outbounds...'

call SysFileTree ob'.*', 'ob_m', 'do'
if ob_m.0 = 0
  then
    do
      say
      say 'Dir 'ob' not found! Nothing to do (1)'
      return
    end

'@echo off'

do m=1 to ob_m.0
  call SysFileTree ob_m.m'\*.pnt', 'ob_pnt', 'do'
  if ob_pnt.0 = 0
    then
      do
        say
        say 'Nothing to do in 'ob_m.m '(2)'
        iterate
      end

  if pos('.', ob_m.m, lastpos('\', ob_m.m) + 1) = 0
    then
      zone = defzone
    else
      zone = x2d(substr(ob_m.m, lastpos('.', ob_m.m) + 1, 3))
  
  do p=1 to ob_pnt.0
    call SysFileTree ob_pnt.p'\*.?lo', 'los', 'fo'
    if los.0 = 0
      then
        do
          say
          say 'Nothing to do in 'ob_pnt.p' (3)'
          iterate
        end

    net = x2d(substr(ob_pnt.p, lastpos('\', ob_pnt.p) + 1, 4))
    node = x2d(substr(ob_pnt.p, lastpos('\', ob_pnt.p) + 5, 4))

    do i=1 to los.0
      say
      call TreatLo los.i
    end

  end

end

return

/* Internal functions */

TreatLo: procedure expose age_p age_t zone net node zipper pkts tics

  parse value date('u') with mmm'/'ddd'/'yyy
  lo = arg(1)
  say 'Processing 'lo
  point = x2d(substr(lo, lastpos('\', lo) + 1, 8))
  say '    System 'zone':'net'/'node'.'point
  tpl = substr(lo, 1, lastpos('.', lo) - 1)

  call SysFileTree tpl'.?sy', 'bsys', 'fo'
  if bsys.0 \= 0
    then
      do
        say '       *** Busy!'
        return
      end

  bsy = tpl'.bsy'
  call lineout bsy,,1
  call stream bsy, 'c', 'close'

  k=0

  do while lines(lo)
    str_lo = linein(lo)
    k=k+1

/* arcmail */

    if (substr(str_lo, 1, 1) = '#') & (pkts = 'yes')
      then
        do
          bndl = substr(str_lo, 2)
          say '   ARCmail 'bndl

          zipper'\unzip -l 'bndl'| rxqueue'
          do queued()
            parse pull line

            if substr(line, 52) \= 'PKT'
              then
                iterate

            parse value line with length eas acls pktdate time pktname
            parse value pktdate with mm'-'dd'-'yy

            if ((dd < ddd - age_p) & (mm = mmm) & (yy = yyy)) | ((dd > ddd - age_p) & (mm < mmm) & (yy = yyy)) | ((dd > ddd - age_p) & (mm > mmm) & (yy < yyy))
              then
                zipper'\zip -do' bndl || pktname' 2> nul'
          end

          zipper'\unzip -Z 'bndl'| rxqueue'
          parse pull line
          if word(line, 4) = '0'
            then
              do
                call charout lo, '~', 1
                call SysFileDelete bndl
                call charout bndl,,1
              end

          iterate

        end

/* tics */

    if (substr(str_lo, 1, 1) = '^') & (tics = 'yes')
      then
        do
          tic = substr(str_lo, 2)
          say '       TIC 'tic
          call stream lo, 'c', 'close'
          do k-1
            str_lo = linein(lo)
          end
          say '      File 'str_lo
          str_lo = linein(lo)

          call SysFileTree tic, 'tiks', 'f'
          do t=1 to tiks.0
            parse value word(tiks.t, 1) with mm'/'dd'/'yy
            if ((dd < ddd - age_t) & (mm = mmm) & (yy = yyy)) | ((dd > ddd - age_t) & (mm < mmm) & (yy = yyy)) | ((dd > ddd - age_t) & (mm > mmm) & (yy < yyy))
              then
                do
                  call stream lo, 'c', 'close'
                  do k-1
                    str_lo = linein(lo)
                  end
                  call charout lo, '~', 1
                  str_lo = linein(lo)
                  call charout lo, '~', 1
                  say 'deleting: 'substr(word(tiks.t, 5), lastpos('\', word(tiks.t, 5) + 1))
                  call SysFileDelete tic
                end
          end

        end
  end

  call stream lo, 'c', 'close'
  call SysFileDelete bsy

return
